@@ -1,7 +1,6 @@
 /* Emacs style mode select   -*- C++ -*-
  *-----------------------------------------------------------------------------
  *
- * $Id: i_sound.c,v 1.16.2.5 2002/07/20 18:08:37 proff_fs Exp $
  *
  *  PrBoom a Doom port merged with LxDoom and LSDLDoom
  *  based on BOOM, a modified and improved DOOM engine
@@ -31,9 +30,6 @@
  *-----------------------------------------------------------------------------
  */
 
-static const char
-rcsid[] = "$Id: i_sound.c,v 1.16.2.5 2002/07/20 18:08:37 proff_fs Exp $";
-
 #ifdef HAVE_CONFIG_H
 #include "../config.h"
 #endif
@@ -208,7 +204,6 @@ static void updateSoundParams(int handle, int volume, int seperation, int pitch)
     // Per left/right channel.
     //  x^2 seperation,
     //  adjust volume properly.
-    volume *= 8;
     leftvol = volume - ((volume*seperation*seperation) >> 16);
     seperation = seperation - 257;
     rightvol= volume - ((volume*seperation*seperation) >> 16);
