@@ -1,7 +1,6 @@
 /* Emacs style mode select   -*- C++ -*-
  *-----------------------------------------------------------------------------
  *
- * $Id: i_system.c,v 1.6.2.3 2002/07/21 10:20:47 cph Exp $
  *
  *  PrBoom a Doom port merged with LxDoom and LSDLDoom
  *  based on BOOM, a modified and improved DOOM engine
@@ -32,9 +31,6 @@
  *-----------------------------------------------------------------------------
  */
 
-static const char
-rcsid[] = "$Id: i_system.c,v 1.6.2.3 2002/07/21 10:20:47 cph Exp $";
-
 #include <stdio.h>
 
 #include <stdarg.h>
@@ -117,12 +113,14 @@ const char* I_SigString(char* buf, size_t sz, int signum)
   return buf;
 }
 
+#ifndef PRBOOM_SERVER
+
 // Return the path where the executable lies -- Lee Killough
 // proff_fs 2002-07-04 - moved to i_system
 #ifdef _WIN32
 char *I_DoomExeDir(void)
 {
-  static const char current_dir_dummy[] = {"./"};
+  static const char current_dir_dummy[] = {"."}; // proff - rem extra slash 8/21/03
   static char *base;
   if (!base)        // cache multiple requests
     {
@@ -146,7 +144,7 @@ char *I_DoomExeDir(void)
 #else
 // cph - V.Aguilar (5/30/99) suggested return ~/.lxdoom/, creating
 //  if non-existant
-static const char prboom_dir[] = {"/.prboom/"};
+static const char prboom_dir[] = {"/.prboom"}; // Mead rem extra slash 8/21/03
 
 char *I_DoomExeDir(void)
 {
@@ -251,3 +249,4 @@ char* I_FindFile(const char* wfname, const char* ext)
   return NULL;
 }
 
+#endif // PRBOOM_SERVER
