@@ -1,7 +1,6 @@
 /* Emacs style mode select   -*- C++ -*-
  *-----------------------------------------------------------------------------
  *
- * $Id: i_video.c,v 1.18.2.7 2002/07/20 18:08:37 proff_fs Exp $
  *
  *  PrBoom a Doom port merged with LxDoom and LSDLDoom
  *  based on BOOM, a modified and improved DOOM engine
@@ -31,9 +30,6 @@
  *-----------------------------------------------------------------------------
  */
 
-static const char
-rcsid[] = "$Id: i_video.c,v 1.18.2.7 2002/07/20 18:08:37 proff_fs Exp $";
-
 #ifdef HAVE_CONFIG_H
 #include "../config.h"
 #endif
@@ -85,6 +81,7 @@ int             leds_always_off = 0; // Expected by m_misc, not relevant
 
 // Mouse handling
 extern int     usemouse;        // config file var
+static boolean grabMouse;       // internal var
 
 /////////////////////////////////////////////////////////////////////////////////
 // Keyboard handling
@@ -242,7 +239,7 @@ void I_StartTic (void)
 {
   SDL_Event Event;
   {
-    int should_be_grabbed = usemouse &&
+    int should_be_grabbed = grabMouse &&
       !(paused || (gamestate != GS_LEVEL) || demoplayback);
 
     if (mouse_currently_grabbed != should_be_grabbed)
@@ -269,6 +266,9 @@ void I_StartFrame (void)
 
 static void I_InitInputs(void)
 {
+  // check if the user wants to grab the mouse
+  grabMouse = M_CheckParm("-nomouse") ? false : usemouse ? true : false;
+
   I_InitJoystick();
 }
 /////////////////////////////////////////////////////////////////////////////
