@@ -1,7 +1,6 @@
 /* Emacs style mode select   -*- C++ -*-
  *-----------------------------------------------------------------------------
  *
- * $Id: d_client.c,v 1.12.2.1 2002/07/20 18:08:34 proff_fs Exp $
  *
  *  PrBoom a Doom port merged with LxDoom and LSDLDoom
  *  based on BOOM, a modified and improved DOOM engine
@@ -115,6 +114,7 @@ void D_InitNetGame (void)
     // Get info from the setup packet
     consoleplayer = sinfo->yourplayer;
     compatibility_level = sinfo->complevel;
+    G_Compatibility();
     startskill = sinfo->skill;
     deathmatch = sinfo->deathmatch;
     startmap = sinfo->level;
@@ -245,6 +245,7 @@ boolean D_NetGetWad(const char* name)
 
 void NetUpdate(void)
 {
+  static int lastmadetic;
   if (server) { // Receive network packets
     size_t recvlen;
     packet_header_t *packet = Z_Malloc(10000, PU_STATIC, NULL);
@@ -254,20 +255,21 @@ void NetUpdate(void)
   {
     byte *p = (void*)(packet+1);
     int tics = *p++;
-    if (packet->tic > (unsigned)remotetic) { // Missed some
+    unsigned long ptic = doom_ntohl(packet->tic);
+    if (ptic > (unsigned)remotetic) { // Missed some
       packet->type = PKT_RETRANS;
-      packet->tic = remotetic;
+      packet->tic = doom_htonl(remotetic);
       *(byte*)(packet+1) = consoleplayer;
       I_SendPacket(packet, sizeof(*packet)+1);
     } else {
-      if (packet->tic + tics <= (unsigned)remotetic) break; // Will not improve things
-      remotetic = packet->tic;
+      if (ptic + tics <= (unsigned)remotetic) break; // Will not improve things
+      remotetic = ptic;
       while (tics--) {
         int players = *p++;
         while (players--) {
-    int n = *p++;
-    RawToTic(&netcmds[n][remotetic%BACKUPTICS], p);
-    p += sizeof(ticcmd_t);
+            int n = *p++;
+            RawToTic(&netcmds[n][remotetic%BACKUPTICS], p);
+            p += sizeof(ticcmd_t);
         }
         remotetic++;
       }
@@ -275,8 +277,8 @@ void NetUpdate(void)
   }
   break;
       case PKT_RETRANS: // Resend request
-  remotesend = packet->tic;
-  break;
+          remotesend = doom_ntohl(packet->tic);
+          break;
       case PKT_DOWN: // Server downed
   {
     int j;
@@ -294,6 +296,13 @@ void NetUpdate(void)
   queuedpacket[numqueuedpackets-1] = Z_Malloc(recvlen, PU_STATIC, NULL);
   memcpy(queuedpacket[numqueuedpackets-1], packet, recvlen);
   break;
+      case PKT_BACKOFF:
+        /* cph 2003-09-18 -
+	 * The server sends this when we have got ahead of the other clients. We should
+	 * stall the input side on this client, to allow other clients to catch up.
+	 */
+        lastmadetic++;
+	break;
       default: // Other packet, unrecognised or redundant
   break;
       }
@@ -301,9 +310,8 @@ void NetUpdate(void)
     Z_Free(packet);
   }
   { // Build new ticcmds
-    static int lastmadetic;
     int newtics = I_GetTime() - lastmadetic;
-
+    newtics = (newtics > 0 ? newtics : 0);
     lastmadetic += newtics;
     while (newtics--) {
       I_StartTic();
@@ -320,7 +328,7 @@ void NetUpdate(void)
   size_t pkt_size = sizeof(packet_header_t) + 2 + sendtics * sizeof(ticcmd_t);
   packet_header_t *packet = Z_Malloc(pkt_size, PU_STATIC, NULL);
 
-  packet->tic = maketic - sendtics;
+  packet->tic = doom_htonl(maketic - sendtics);
   packet->type = PKT_TICC;
   *(byte*)(packet+1) = sendtics;
   *(((byte*)(packet+1))+1) = consoleplayer;
@@ -363,7 +371,7 @@ void D_NetSendMisc(netmisctype_t type, size_t len, void* data)
     packet_header_t *packet = Z_Malloc(size, PU_STATIC, NULL);
     int *p = (void*)(packet+1);
 
-    packet->tic = gametic;
+    packet->tic = doom_htonl(gametic);
     packet->type = PKT_EXTRA;
     *p++ = LONG(type); *p++ = LONG(consoleplayer); *p++ = LONG(len);
     memcpy(p, data, len);
@@ -377,7 +385,7 @@ static void CheckQueuedPackets(void)
 {
   int i;
   for (i=0; (unsigned)i<numqueuedpackets; i++)
-    if (queuedpacket[i]->tic <= (unsigned)gametic)
+    if (doom_ntohl(queuedpacket[i]->tic) <= (unsigned)gametic)
       switch (queuedpacket[i]->type) {
       case PKT_QUIT: // Player quit the game
   {
@@ -413,7 +421,7 @@ static void CheckQueuedPackets(void)
     packet_header_t **newqueue = NULL;
 
     for (i=0; (unsigned)i<numqueuedpackets; i++)
-      if (queuedpacket[i]->tic > (unsigned)gametic) {
+      if (doom_ntohl(queuedpacket[i]->tic) > (unsigned)gametic) {
   newqueue = Z_Realloc(newqueue, ++newnum * sizeof *newqueue,
            PU_STATIC, NULL);
   newqueue[newnum-1] = queuedpacket[i];
@@ -473,7 +481,7 @@ void D_QuitNetGame (void)
 
   if (!server) return;
   buf[sizeof(packet_header_t)] = consoleplayer;
-  packet->type = PKT_QUIT; packet->tic = gametic;
+  packet->type = PKT_QUIT; packet->tic = doom_htonl(gametic);
 
   for (i=0; i<4; i++) {
     I_SendPacket(packet, 1 + sizeof(packet_header_t));
