@@ -1,7 +1,6 @@
 /* Emacs style mode select   -*- C++ -*-
  *-----------------------------------------------------------------------------
  *
- * $Id: d_server.c,v 1.14.2.1 2002/07/20 18:08:34 proff_fs Exp $
  *
  *  PrBoom a Doom port merged with LxDoom and LSDLDoom
  *  based on BOOM, a modified and improved DOOM engine
@@ -35,7 +34,6 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <time.h>
-//#include <sys/time.h>
 #include <limits.h>
 #include <string.h>
 #ifdef HAVE_UNISTD_H
@@ -45,13 +43,12 @@
 #include <fcntl.h>
 #include <signal.h>
 #include <sys/types.h>
-//#include <sys/socket.h>
-//#include <netinet/in.h>
 
 #include "doomtype.h"
 #include "protocol.h"
 #include "i_network.h"
 #include "i_system.h"
+#include "m_swap.h"
 
 #ifndef HAVE_GETOPT
 /* The following code for getopt is from the libc-source of FreeBSD,
@@ -230,6 +227,18 @@ byte def_game_options[GAME_OPTIONS_SIZE] = \
   /* Zeroes for all compatibility stuff */
 };
 
+#define nosuch "NOSUCHCONFIGITEM"
+
+const char* gameopt_config_names[] = {
+"monsters_remember",nosuch,"weapon_recoil",nosuch,nosuch,"player_bobbing",nosuch,nosuch,nosuch,"demo_insurance",
+nosuch,nosuch,nosuch,nosuch, // RNG seed
+"monster_infighting","player_helpers",nosuch,nosuch,
+nosuch,nosuch, // distfriend
+"monster_backing","monster_avoid_hazards","monster_friction","help_friends","dog_jumping","monkeys",
+"comp_telefrag","comp_dropoff","comp_vile","comp_pain","comp_skull","comp_blazing","comp_doorlight","comp_model","comp_god","comp_falloff","comp_floors","comp_skymap","comp_pursuit","comp_doorstuck","comp_staylift","comp_zombie","comp_stairs","comp_infcheat","comp_zerotags","comp_moveblock","comp_respawn","comp_sound" };
+
+const int num_gameopts = sizeof gameopt_config_names / sizeof gameopt_config_names[0];
+
 int verbose;
 
 void sig_handler(int signum)
@@ -266,6 +275,40 @@ static void I_InitSockets(Uint16 port)
 }
 #endif
 
+long int ptic(packet_header_t* p)
+{
+    return doom_ntohl(p->tic);
+}
+
+
+
+void read_config_file(FILE* fp, struct setup_packet_s* sp)
+{
+  byte* gameopt = sp->game_options;
+
+  while (!feof(fp)) {
+    char  def[80];
+    char  strparm[100];
+    if (fscanf (fp, "%79s %99[^\n]\n", def, strparm) == 2) {
+      int v = atoi(strparm);
+      if (!strcmp(def,"default_skill")) {
+        if (verbose) printf("config file sets default_skill to %d\n",v);
+        sp->skill = v-1;
+      } else if (!strcmp(def,"default_compatibility_level")) {
+        if (verbose) printf("config file sets compatibility_level to %d\n",v);
+        sp->complevel = v;
+      } else {
+        int i;
+        for (i=0; i<num_gameopts; i++) {
+	  if (!!strcmp(gameopt_config_names[i],def)) continue;
+	  if (verbose) printf("config file sets %s to %d\n",def,v);
+	  gameopt[i] = v;
+	}
+      }
+    }
+  }
+}
+
 int main(int argc, char** argv)
 {
   int localport = 5030, numplayers = 2, xtratics = 0, ticdup = 1;
@@ -279,8 +322,16 @@ int main(int argc, char** argv)
     byte *gameopt = setupinfo.game_options;
 
     memcpy(gameopt, &def_game_options, sizeof (setupinfo.game_options));
-    while ((opt = getopt(argc, argv, "p:e:l:adrfns:c:N:x:t:vw:")) != EOF)
+    while ((opt = getopt(argc, argv, "c:t:x:p:e:l:adrfns:N:vw:")) != EOF)
       switch (opt) {
+      case 'c':
+        {
+	  FILE *cf = fopen(optarg,"r");
+	  if (!cf) { perror("fopen"); return -1; }
+	  read_config_file(cf,&setupinfo);
+	  fclose(cf);
+	}
+	break;
       case 't':
   if (optarg) ticdup = atoi(optarg);
   break;
@@ -312,7 +363,7 @@ int main(int argc, char** argv)
   setupinfo.game_options[8] = 1;
   break;
       case 's':
-  if (optarg) setupinfo.skill = atoi(optarg);
+  if (optarg) setupinfo.skill = atoi(optarg)-1;
   break;
       case 'N':
   if (optarg) setupinfo.players = numplayers = atoi(optarg);
@@ -373,6 +424,7 @@ int main(int argc, char** argv)
   {
     int remoteticfrom[MAXPLAYERS] = { 0, 0, 0, 0 };
     int remoteticto[MAXPLAYERS] = { 0, 0, 0, 0 };
+    int backoffcounter[MAXPLAYERS] = { 0, 0, 0, 0 };
     int curplayers = 0;
     boolean ingame = false;
     ticcmd_t netcmds[MAXPLAYERS][BACKUPTICS];
@@ -411,6 +463,9 @@ int main(int argc, char** argv)
 
     printf("Join by ");
     I_PrintAddress(stdout, &remoteaddr[n]);
+#ifdef USE_SDL_NET
+    printf(" (channel %d)",remoteaddr[n]);
+#endif
     putc('\n', stdout);
     {
       int i;
@@ -457,35 +512,35 @@ int main(int argc, char** argv)
         int from = *(((byte*)(packet+1))+1);
 
         if (verbose>2)
-    printf("tics %d - %d from %d\n", packet->tic, packet->tic + tics - 1, from);
-        if (packet->tic > remoteticfrom[from]) {
-    // Missed tics, so request a resend
-    packet->tic = remoteticfrom[from];
-    packet->type = PKT_RETRANS;
-    I_SendPacketTo(packet, sizeof *packet, remoteaddr+from);
+            printf("tics %d - %d from %d\n", ptic(packet), ptic(packet) + tics - 1, from);
+        if (ptic(packet) > remoteticfrom[from]) {
+            // Missed tics, so request a resend
+            packet->tic = doom_htonl(remoteticfrom[from]);
+            packet->type = PKT_RETRANS;
+            I_SendPacketTo(packet, sizeof *packet, remoteaddr+from);
         } else {
-    ticcmd_t *newtic = (void*)(((byte*)(packet+1))+2);
-    if (packet->tic + tics < remoteticfrom[from]) break; // Won't help
-    remoteticfrom[from] = packet->tic;
-    while (tics--)
-      netcmds[from][remoteticfrom[from]++%BACKUPTICS] =  *newtic++;
+            ticcmd_t *newtic = (void*)(((byte*)(packet+1))+2);
+            if (ptic(packet) + tics < remoteticfrom[from]) break; // Won't help
+            remoteticfrom[from] = ptic(packet);
+            while (tics--)
+              netcmds[from][remoteticfrom[from]++%BACKUPTICS] =  *newtic++;
         }
       }
       break;
     case PKT_RETRANS:
       {
         int from = *(byte*)(packet+1);
-        if (verbose>2) printf("%d requests resend from %d\n", from, packet->tic);
-        remoteticto[from] = packet->tic;
+        if (verbose>2) printf("%d requests resend from %d\n", from, ptic(packet));
+        remoteticto[from] = ptic(packet);
       }
       break;
     case PKT_QUIT:
       {
         int from = *(byte*)(packet+1);
 
-        if (verbose>2) printf("%d quits at %d\n", from, packet->tic);
+        if (verbose>2) printf("%d quits at %d\n", from, ptic(packet));
         if (playerleftgame[from] == INT_MAX) { // In the game
-    playerleftgame[from] = packet->tic;
+    playerleftgame[from] = ptic(packet);
     if (ingame && !--curplayers) exit(0); // All players have exited
         }
       }
@@ -556,7 +611,7 @@ int main(int argc, char** argv)
         packet_header_t *packet = malloc(sizeof(packet_header_t) + 1 +
          tics * (1 + numplayers * (1 + sizeof(ticcmd_t))));
         byte *p = (void*)(packet+1);
-        packet->type = PKT_TICS; packet->tic = remoteticto[i] - xtratics;
+        packet->type = PKT_TICS; packet->tic = doom_htonl(remoteticto[i] - xtratics);
         *p++ = tics;
         if (verbose>1) printf("sending %d tics to %d\n", tics, i);
         while (tics--) {
@@ -576,6 +631,19 @@ int main(int argc, char** argv)
         I_SendPacketTo(packet, p - ((byte*)packet), remoteaddr+i);
         free(packet);
       }
+      {
+        if (remoteticfrom[i] == remoteticto[i]) {
+	  backoffcounter[i] = 0;
+	} else if (remoteticfrom[i] > remoteticto[i]+1) {
+	  if ((backoffcounter[i] += remoteticfrom[i] - remoteticto[i] - 1) > 100) {
+	    packet_header_t *packet = malloc(sizeof(packet_header_t));
+	    packet->type = PKT_BACKOFF; packet->tic = doom_htonl(remoteticto[i]);
+	    I_SendPacketTo(packet,sizeof *packet,remoteaddr+i);
+	    backoffcounter[i] = 0;
+	    if (verbose) fprintf(stderr,"telling client %d to back off\n",i);
+	  }
+	}
+      }
     }
       }
     }
