@@ -1,7 +1,6 @@
 /* Emacs style mode select   -*- C++ -*-
  *-----------------------------------------------------------------------------
  *
- * $Id: g_game.c,v 1.30.2.8 2002/07/21 16:43:22 cph Exp $
  *
  *  PrBoom a Doom port merged with LxDoom and LSDLDoom
  *  based on BOOM, a modified and improved DOOM engine
@@ -34,9 +33,6 @@
  *-----------------------------------------------------------------------------
  */
 
-static const char
-rcsid[] = "$Id: g_game.c,v 1.30.2.8 2002/07/21 16:43:22 cph Exp $";
-
 #include <stdio.h>
 #include <stdarg.h>
 #include <stdlib.h>
@@ -1853,7 +1849,7 @@ extern int monsters_remember, default_monsters_remember;
  *  introduced.
  */
 
-static void G_Compatibility(void)
+void G_Compatibility(void)
 {
   static const complevel_t fix_levels[COMP_NUM] = {
     mbf_compatibility, /* comp_telefrag - monsters used to telefrag only
@@ -1890,6 +1886,7 @@ static void G_Compatibility(void)
            * mancubi shots going thru walls */
     prboom_2_compatibility, /* comp_respawn - objects which aren't on the map
                              * at game start respawn at (0,0) */
+    boom_compatibility_compatibility,  /* comp_sound - see s_sound.c */
   };
   int i;
   for (i=0; i<COMP_NUM; i++)
