@@ -1,7 +1,6 @@
 /* Emacs style mode select   -*- C++ -*-
  *-----------------------------------------------------------------------------
  *
- * $Id: gl_main.c,v 1.35.2.5 2002/07/27 15:58:45 proff_fs Exp $
  *
  *  PrBoom a Doom port merged with LxDoom and LSDLDoom
  *  based on BOOM, a modified and improved DOOM engine
@@ -30,6 +29,34 @@
  *---------------------------------------------------------------------
  */
 
+#include "z_zone.h"
+#ifdef _WIN32
+#define WIN32_LEAN_AND_MEAN
+#include <windows.h>
+#endif
+#ifndef CALLBACK
+#define CALLBACK
+#endif
+#include <stdio.h>
+#include <string.h>
+#include <math.h>
+#include <SDL.h>
+#include <SDL_opengl.h>
+#include "doomtype.h"
+#include "w_wad.h"
+#include "m_argv.h"
+#include "d_event.h"
+#include "v_video.h"
+#include "doomstat.h"
+#include "r_bsp.h"
+#include "r_main.h"
+#include "r_draw.h"
+#include "r_sky.h"
+#include "r_plane.h"
+#include "r_data.h"
+#include "p_maputl.h"
+#include "m_bbox.h"
+#include "lprintf.h"
 #include "gl_intern.h"
 #include "gl_struct.h"
 
@@ -47,10 +74,11 @@ int gl_mipmap_filter;
 int gl_drawskys=true;
 int gl_sortsprites=true;
 int gl_texture_filter_anisotropic = 0;
-int gl_use_paletted_texture = 1;
-int gl_use_shared_texture_palette = 1;
+int gl_use_paletted_texture = 0;
+int gl_use_shared_texture_palette = 0;
 int gl_paletted_texture = 0;
 int gl_shared_texture_palette = 0;
+int gl_sprite_offset;	// item out of floor offset Mead 8/13/03
 
 GLuint gld_DisplayList=0;
 int fog_density=200;
@@ -222,26 +250,10 @@ static void gld_StaticLightAlpha(float light, float alpha)
   player_t *player;
   player = &players[displayplayer];
 
-  if (gl_shared_texture_palette) {
-    if (player->fixedcolormap)
-    {
-      glColor4f(1.0f, 1.0f, 1.0f, alpha);
-      return;
-    }
-  } else {
-    if (player->fixedcolormap == 32)
-    {
-      glColor4f(0.5f, 1.0f, 0.0f, alpha);
-      return;
-    }
-    else
-      if (player->fixedcolormap)
-      {
-        glColor4f(1.0f, 1.0f, 1.0f, alpha);
-        return;
-      }
-  }
-  glColor4f(light, light, light, alpha);
+  if (player->fixedcolormap)
+    glColor4f(1.0f, 1.0f, 1.0f, alpha);
+  else
+    glColor4f(light, light, light, alpha);
 }
 
 #define gld_StaticLight(light) gld_StaticLightAlpha(light, 1.0f)
@@ -276,15 +288,21 @@ void gld_InitExtensions(const char *_extensions)
     else if (strcasecmp(extension, "GL_EXT_paletted_texture") == 0) {
       if (gl_use_paletted_texture) {
         gl_paletted_texture = true;
-        glColorTableEXT = SDL_GL_GetProcAddress("glColorTableEXT");
-        lprintf(LO_INFO,"using GL_EXT_paletted_texture\n",glGetString(GL_VENDOR));
+        gld_ColorTableEXT = SDL_GL_GetProcAddress("glColorTableEXT");
+	if (gld_ColorTableEXT == NULL)
+	  gl_paletted_texture = false;
+	else
+          lprintf(LO_INFO,"using GL_EXT_paletted_texture\n",glGetString(GL_VENDOR));
       }
     }
     else if (strcasecmp(extension, "GL_EXT_shared_texture_palette") == 0)
       if (gl_use_shared_texture_palette) {
         gl_shared_texture_palette = true;
-        glColorTableEXT = SDL_GL_GetProcAddress("glColorTableEXT");
-        lprintf(LO_INFO,"using GL_EXT_shared_texture_palette\n",glGetString(GL_VENDOR));
+        gld_ColorTableEXT = SDL_GL_GetProcAddress("glColorTableEXT");
+	if (gld_ColorTableEXT == NULL)
+	  gl_shared_texture_palette = false;
+	else
+          lprintf(LO_INFO,"using GL_EXT_shared_texture_palette\n",glGetString(GL_VENDOR));
       }
 
     extension = p;
@@ -710,19 +728,19 @@ void gld_FillBlock(int x, int y, int width, int height, int col)
 
 void gld_SetPalette(int palette)
 {
+  static int last_palette = 0;
   extra_red=0.0f;
   extra_green=0.0f;
   extra_blue=0.0f;
   extra_alpha=0.0f;
+  if (palette < 0)
+    palette = last_palette;
+  last_palette = palette;
   if (gl_shared_texture_palette) {
-    static int last_palette = 0;
     const unsigned char *playpal;
     unsigned char pal[1024];
     int i;
 
-    if (palette < 0)
-      palette = last_palette;
-    last_palette = palette;
     playpal = W_CacheLumpName("PLAYPAL");
     playpal += (768*palette);
     for (i=0; i<256; i++) {
@@ -743,7 +761,7 @@ void gld_SetPalette(int palette)
     pal[transparent_pal_index*4+1]=0;
     pal[transparent_pal_index*4+2]=0;
     pal[transparent_pal_index*4+3]=0;
-    glColorTableEXT(GL_SHARED_TEXTURE_PALETTE_EXT, GL_RGBA, 256, GL_RGBA, GL_UNSIGNED_BYTE, pal);
+    gld_ColorTableEXT(GL_SHARED_TEXTURE_PALETTE_EXT, GL_RGBA, 256, GL_RGBA, GL_UNSIGNED_BYTE, pal);
     W_UnlockLumpName("PLAYPAL");
   } else {
     if (palette>0)
@@ -1775,6 +1793,45 @@ static float yaw      = 0.0f;
 static float inv_yaw  = 0.0f;
 static float pitch    = 0.0f;
 
+#define __glPi 3.14159265358979323846
+
+void infinitePerspective(GLdouble fovy, GLdouble aspect, GLdouble znear)
+{
+	GLdouble left, right, bottom, top;
+	GLdouble m[16];
+
+	top = znear * tan(fovy * __glPi / 360.0);
+	bottom = -top;
+	left = bottom * aspect;
+	right = top * aspect;
+
+	//qglFrustum(left, right, bottom, top, znear, zfar);
+
+	m[ 0] = (2 * znear) / (right - left);
+	m[ 4] = 0;
+	m[ 8] = (right + left) / (right - left);
+	m[12] = 0;
+
+	m[ 1] = 0;
+	m[ 5] = (2 * znear) / (top - bottom);
+	m[ 9] = (top + bottom) / (top - bottom);
+	m[13] = 0;
+
+	m[ 2] = 0;
+	m[ 6] = 0;
+	//m[10] = - (zfar + znear) / (zfar - znear);
+	//m[14] = - (2 * zfar * znear) / (zfar - znear);
+	m[10] = -1;
+	m[14] = -2 * znear;
+
+	m[ 3] = 0;
+	m[ 7] = 0;
+	m[11] = -1;
+	m[15] = 0;
+
+	glMultMatrixd(m);
+}
+
 void gld_StartDrawScene(void)
 {
   float trY ;
@@ -1816,7 +1873,8 @@ void gld_StartDrawScene(void)
   glMatrixMode(GL_PROJECTION);
   glLoadIdentity();
 
-  gluPerspective(64.0f, 320.0f/200.0f, (float)gl_nearclip/100.0f, (float)gl_farclip/100.0f);
+  //gluPerspective(64.0f, 320.0f/200.0f, (float)gl_nearclip/100.0f, (float)gl_farclip/100.0f);
+  infinitePerspective(64.0f, 320.0f/200.0f, (float)gl_nearclip/100.0f);
 
   glMatrixMode(GL_MODELVIEW);
   glLoadIdentity();
@@ -1838,6 +1896,7 @@ void gld_StartDrawScene(void)
 
 void gld_EndDrawScene(void)
 {
+  player_t *player = &players[displayplayer];
   extern void R_DrawPlayerSprites (void);
 
   glDisable(GL_POLYGON_SMOOTH);
@@ -1851,6 +1910,20 @@ void gld_EndDrawScene(void)
   { // don't draw on side views
     R_DrawPlayerSprites ();
   }
+  if (player->fixedcolormap == 32) {
+		glBlendFunc(GL_ONE_MINUS_DST_COLOR, GL_ZERO);
+		glColor4f(1,1,1,1);
+    glBindTexture(GL_TEXTURE_2D, 0);
+    last_gltexture = NULL;
+    last_cm = -1;
+    glBegin(GL_TRIANGLE_STRIP);
+  		glVertex2f( 0.0f, 0.0f);
+	  	glVertex2f( 0.0f, (float)SCREENHEIGHT);
+		  glVertex2f( (float)SCREENWIDTH, 0.0f);
+		  glVertex2f( (float)SCREENWIDTH, (float)SCREENHEIGHT);
+    glEnd();
+		glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
+  }
   if (extra_alpha>0.0f)
   {
     glDisable(GL_ALPHA_TEST);
@@ -2437,7 +2510,8 @@ static void gld_DrawSprite(GLSprite *sprite)
   gld_BindPatch(sprite->gltexture,sprite->cm);
   glMatrixMode(GL_MODELVIEW);
   glPushMatrix();
-  glTranslatef(sprite->x,sprite->y,sprite->z);
+  // Bring items up out of floor by configurable amount times .01 Mead 8/13/03
+  glTranslatef(sprite->x,sprite->y+ (.01f * (float)gl_sprite_offset),sprite->z);
   glRotatef(inv_yaw,0.0f,1.0f,0.0f);
   if(sprite->shadow)
   {
