@@ -1,7 +1,6 @@
 /* Emacs style mode select   -*- C++ -*-
  *-----------------------------------------------------------------------------
  *
- * $Id: i_udp_sdl.c,v 1.8.2.1 2002/07/20 18:08:34 proff_fs Exp $
  *
  *  PrBoom a Doom port merged with LxDoom and LSDLDoom
  *  based on BOOM, a modified and improved DOOM engine
@@ -194,7 +193,8 @@ void I_CloseSocket(UDP_SOCKET sock)
 
 UDP_CHANNEL I_RegisterPlayer(IPaddress *ipaddr)
 {
-  return(SDLNet_UDP_Bind(udp_socket, -1, ipaddr));
+  static int freechannel;
+  return(SDLNet_UDP_Bind(udp_socket, freechannel++, ipaddr));
 }
 
 void I_UnRegisterPlayer(UDP_CHANNEL channel)
