@@ -1,7 +1,6 @@
 /* Emacs style mode select   -*- C++ -*-
  *-----------------------------------------------------------------------------
  *
- * $Id: m_misc.c,v 1.26.2.7 2002/07/27 15:58:45 proff_fs Exp $
  *
  *  PrBoom a Doom port merged with LxDoom and LSDLDoom
  *  based on BOOM, a modified and improved DOOM engine
@@ -32,9 +31,6 @@
  *
  *-----------------------------------------------------------------------------*/
 
-static const char
-rcsid[] = "$Id: m_misc.c,v 1.26.2.7 2002/07/27 15:58:45 proff_fs Exp $";
-
 #ifdef HAVE_CONFIG_H
 #include "../config.h"
 #endif
@@ -179,6 +175,7 @@ extern int gl_drawskys;
 extern int gl_sortsprites;
 extern int gl_use_paletted_texture;
 extern int gl_use_shared_texture_palette;
+extern int gl_sprite_offset;
 #endif
 extern int mouseSensitivity_horiz,mouseSensitivity_vert;  // killough
 
@@ -308,6 +305,7 @@ default_t defaults[] =
   {"comp_model",{&default_comp[comp_model]},{0},0,1,def_bool,ss_comp,&comp[comp_model]},
   {"comp_zerotags",{&default_comp[comp_zerotags]},{0},0,1,def_bool,ss_comp,&comp[comp_zerotags]},
   {"comp_moveblock",{&default_comp[comp_moveblock]},{0},0,1,def_bool,ss_comp,&comp[comp_moveblock]},
+  {"comp_sound",{&default_comp[comp_sound]},{0},0,1,def_bool,ss_comp,&comp[comp_sound]},
 
   {"Sound settings",{NULL},{0},UL,UL,def_none,ss_none},
   {"sound_card",{&snd_card},{-1},-1,7,       // jff 1/18/98 allow Allegro drivers
@@ -339,6 +337,8 @@ default_t defaults[] =
    def_int,ss_none},
   {"screen_height",{&desired_screenheight},{480},200,1200,
    def_int,ss_none},
+  {"gl_sprite_offset",{&gl_sprite_offset},{0}, 0, 5,
+   def_int,ss_none}, // amount to bring items out of floor (GL) Mead 8/13/03
 #endif
   {"fake_contrast",{&fake_contrast},{1},0,1,
    def_bool,ss_none}, /* cph - allow crappy fake contrast to be disabled */
@@ -375,9 +375,9 @@ default_t defaults[] =
    def_bool,ss_none},
   {"gl_sortsprites",{&gl_sortsprites},{1},0,1,
    def_bool,ss_none},
-  {"gl_use_paletted_texture",{&gl_use_paletted_texture},{1},0,1,
+  {"gl_use_paletted_texture",{&gl_use_paletted_texture},{0},0,1,
    def_bool,ss_none},
-  {"gl_use_shared_texture_palette",{&gl_use_shared_texture_palette},{1},0,1,
+  {"gl_use_shared_texture_palette",{&gl_use_shared_texture_palette},{0},0,1,
    def_bool,ss_none},
 #endif
 
@@ -618,6 +618,8 @@ default_t defaults[] =
    def_colour,ss_auto}, // color used for lines with no height changes
   {"mapcolor_sprt", {&mapcolor_sprt}, {112},0,255,  // green
    def_colour,ss_auto}, // color used as things
+  {"mapcolor_item", {&mapcolor_item}, {231},0,255,  // yellow
+   def_colour,ss_auto}, // color used for counted items
   {"mapcolor_hair", {&mapcolor_hair}, {208},0,255,  // white
    def_colour,ss_auto}, // color used for dot crosshair denoting center of map
   {"mapcolor_sngl", {&mapcolor_sngl}, {208},0,255,  // white
