@@ -1,7 +1,6 @@
-/* Emacs style mode select   -*- C++ -*- 
+/* Emacs style mode select   -*- C++ -*-
  *-----------------------------------------------------------------------------
  *
- * $Id: mmus2mid.c,v 1.6 2000/11/22 21:46:48 proff_fs Exp $
  *
  *  PrBoom a Doom port merged with LxDoom and LSDLDoom
  *  based on BOOM, a modified and improved DOOM engine
@@ -9,7 +8,7 @@
  *  id Software, Chi Hoang, Lee Killough, Jim Flynn, Rand Phares, Ty Halderman
  *  Copyright (C) 1999-2000 by
  *  Jess Haas, Nicolas Kalkhof, Colin Phipps, Florian Schulze
- *  
+ *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License
  *  as published by the Free Software Foundation; either version 2
@@ -22,12 +21,12 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
  *  02111-1307, USA.
  *
- * DESCRIPTION:  
+ * DESCRIPTION:
  *  This file supports conversion of MUS format music in memory
- *  to MIDI format 1 music in memory. 
+ *  to MIDI format 1 music in memory.
  *
  *  The primary routine, mmus2mid, converts a block of memory in MUS format
  *  to an Allegro MIDI structure. This supports playing MUS lumps in a wad
@@ -47,7 +46,6 @@
  *-----------------------------------------------------------------------------
  */
 
-static const char rcsid[] = "$Id: mmus2mid.c,v 1.6 2000/11/22 21:46:48 proff_fs Exp $";
 
 #include <ctype.h>
 #include <stdio.h>
@@ -117,27 +115,27 @@ static TrackInfo track[MIDI_TRACKS];
 // initial track size allocation
 #define TRACKBUFFERSIZE 1024
 
-// lookup table MUS -> MID controls 
-static UBYTE MUS2MIDcontrol[15] = 
+// lookup table MUS -> MID controls
+static UBYTE MUS2MIDcontrol[15] =
 {
   0,         // Program change - not a MIDI control change
-  0x00,      // Bank select               
-  0x01,      // Modulation pot              
-  0x07,      // Volume                  
-  0x0A,      // Pan pot                 
-  0x0B,      // Expression pot              
-  0x5B,      // Reverb depth                
-  0x5D,      // Chorus depth                
-  0x40,      // Sustain pedal               
-  0x43,      // Soft pedal                
-  0x78,      // All sounds off              
-  0x7B,      // All notes off               
-  0x7E,      // Mono                    
-  0x7F,      // Poly                    
-  0x79       // Reset all controllers           
+  0x00,      // Bank select
+  0x01,      // Modulation pot
+  0x07,      // Volume
+  0x0A,      // Pan pot
+  0x0B,      // Expression pot
+  0x5B,      // Reverb depth
+  0x5D,      // Chorus depth
+  0x40,      // Sustain pedal
+  0x43,      // Soft pedal
+  0x78,      // All sounds off
+  0x7B,      // All notes off
+  0x7E,      // Mono
+  0x7F,      // Poly
+  0x79       // Reset all controllers
 };
 
-// some strings of bytes used in the midi format 
+// some strings of bytes used in the midi format
 
 static UBYTE midikey[]   =
 {0x00,0xff,0x59,0x02,0x00,0x00};        // C major
@@ -372,20 +370,20 @@ int mmus2mid(const UBYTE *mus, MIDI *mididata, UWORD division, int nocomp)
 
   // allocate for midi tempo/key track, allow for end of track
   if (!(mididata->track[0].data =
-      realloc(mididata->track[0].data,sizeof(midikey)+sizeof(miditempo)+4)))  
+      realloc(mididata->track[0].data,sizeof(midikey)+sizeof(miditempo)+4)))
     return MEMALLOC;
 
   // key C major
   memcpy(mididata->track[0].data,midikey,sizeof(midikey));
-  // tempo uS/qnote 
+  // tempo uS/qnote
   memcpy(mididata->track[0].data+sizeof(midikey),miditempo,sizeof(miditempo));
-  mididata->track[0].len = sizeof(midikey)+sizeof(miditempo); 
+  mididata->track[0].len = sizeof(midikey)+sizeof(miditempo);
 
   TrackCnt++;   // music tracks start at 1
 
   // process the MUS events in the MUS buffer
 
-  do 
+  do
   {
     // get a mus event, decode its type and channel fields
 
@@ -400,7 +398,7 @@ int mmus2mid(const UBYTE *mus, MIDI *mididata, UWORD division, int nocomp)
     {
       // set MIDIchannel and MIDItrack
 
-      MIDIchannel = MUS2MIDchannel[MUSchannel] = 
+      MIDIchannel = MUS2MIDchannel[MUSchannel] =
         (MUSchannel == 15 ? 9 : FirstChannelAvailable(MUS2MIDchannel));
       MIDItrack = MIDIchan2track[MIDIchannel] = (UBYTE)TrackCnt++;
     }
@@ -417,7 +415,7 @@ int mmus2mid(const UBYTE *mus, MIDI *mididata, UWORD division, int nocomp)
     switch(evt)
     {
       case RELEASE_NOTE:
-  	  // killough 10/7/98: Fix noise problems by not allowing compression
+      // killough 10/7/98: Fix noise problems by not allowing compression
       if (!(NewEvent=MidiEvent(mididata,0x90,MIDIchannel,MIDItrack,1)))
         return MEMALLOC;
 
@@ -467,9 +465,9 @@ int mmus2mid(const UBYTE *mus, MIDI *mididata, UWORD division, int nocomp)
               if (TWriteByte(mididata, MIDItrack, (UBYTE)(MUSh.channels+1)))
                 return MEMALLOC;
       }
-          else 
-	    if (TWriteByte(mididata, MIDItrack, 0))
-	      return MEMALLOC;
+          else
+      if (TWriteByte(mididata, MIDItrack, 0))
+        return MEMALLOC;
           break;
 
       case CNTL_CHANGE:
@@ -508,11 +506,11 @@ int mmus2mid(const UBYTE *mus, MIDI *mididata, UWORD division, int nocomp)
     if (last(event))
     {
           ULONG DeltaTime = ReadTime(&musptr); // killough 10/7/98: make local
-	  for (i = 0;i < MIDI_TRACKS; i++) //jff 3/13/98 update all tracks
-	    track[i].deltaT += DeltaTime;  //whether allocated yet or not
+    for (i = 0;i < MIDI_TRACKS; i++) //jff 3/13/98 update all tracks
+      track[i].deltaT += DeltaTime;  //whether allocated yet or not
     }
 
-    } 
+    }
   while ((evt != SCORE_END) && ((size_t)(musptr-mus) < muslen));
 
   if (evt!=SCORE_END)
@@ -523,11 +521,11 @@ int mmus2mid(const UBYTE *mus, MIDI *mididata, UWORD division, int nocomp)
   for (i = 0; i < MIDI_TRACKS; i++)
     if (mididata->track[i].len)
     {       // killough 10/7/98: simplify code
-    	if (TWriteByte(mididata, i, 0x00) || // midi end of track code
-	      TWriteByte(mididata, i, 0xFF) ||
-	      TWriteByte(mididata, i, 0x2F) ||
-	      TWriteByte(mididata, i, 0x00))
-	     return MEMALLOC;
+      if (TWriteByte(mididata, i, 0x00) || // midi end of track code
+        TWriteByte(mididata, i, 0xFF) ||
+        TWriteByte(mididata, i, 0x2F) ||
+        TWriteByte(mididata, i, 0x00))
+       return MEMALLOC;
 
       // jff 1/23/98 fix failure to set data NULL, len 0 for unused tracks
       // shorten allocation to proper length (important for Allegro)
@@ -568,11 +566,11 @@ size_t ReadLength(UBYTE **mid)
 //
 // MidiToMIDI()
 //
-// Convert an in-memory copy of a MIDI format 0 or 1 file to 
+// Convert an in-memory copy of a MIDI format 0 or 1 file to
 // an Allegro MIDI structure, that is valid or has been zeroed
 //
 // Passed a pointer to a memory buffer with MIDI format music in it and a
-// pointer to an Allegro MIDI structure. 
+// pointer to an Allegro MIDI structure.
 //
 // Returns 0 if successful, BADMIDHDR if the buffer is not MIDI format
 //
@@ -605,10 +603,10 @@ int MidiToMIDI(UBYTE *mid,MIDI *mididata)
     while (memcmp(mid,trackhdr,4))    // simply skip non-track data
     {
       mid += 4;
-  	  {
-	      size_t t = ReadLength(&mid);            // seek past header
-	      mid += t;  // killough 10/7/98: prevent mid undefined behavior
-	    }
+      {
+        size_t t = ReadLength(&mid);            // seek past header
+        mid += t;  // killough 10/7/98: prevent mid undefined behavior
+      }
     }
     mid += 4;
     mididata->track[i].len = ReadLength(&mid);  // get length, move mid past it
@@ -642,7 +640,7 @@ static void TWriteLength(UBYTE **midiptr,ULONG length);
 //
 // Passed a pointer to an Allegro MIDI structure
 // Returns nothing
-// 
+//
 static void FreeTracks(MIDI *mididata)
 {
   int i;
@@ -726,7 +724,7 @@ int MIDIToMidi(MIDI *mididata,UBYTE **mid,int *midlen)
       midiptr += sizeof(trackhdr);
       TWriteLength(&midiptr,mididata->track[i].len);  // track length
       // data
-      memcpy(midiptr,mididata->track[i].data,mididata->track[i].len); 
+      memcpy(midiptr,mididata->track[i].data,mididata->track[i].len);
       midiptr += mididata->track[i].len;
     }
   }
