@@ -1,7 +1,6 @@
 /* Emacs style mode select   -*- C++ -*-
  *-----------------------------------------------------------------------------
  *
- * $Id: p_inter.c,v 1.6.2.1 2002/07/20 18:08:36 proff_fs Exp $
  *
  *  PrBoom a Doom port merged with LxDoom and LSDLDoom
  *  based on BOOM, a modified and improved DOOM engine
@@ -30,9 +29,6 @@
  *
  *-----------------------------------------------------------------------------*/
 
-static const char
-rcsid[] = "$Id: p_inter.c,v 1.6.2.1 2002/07/20 18:08:36 proff_fs Exp $";
-
 #include "doomstat.h"
 #include "dstrings.h"
 #include "m_random.h"
@@ -186,7 +182,10 @@ boolean P_GiveWeapon(player_t *player, weapontype_t weapon, boolean dropped)
       P_GiveAmmo(player, weaponinfo[weapon].ammo, deathmatch ? 5 : 2);
 
       player->pendingweapon = weapon;
-      S_StartSound (player->mo, sfx_wpnup|PICKUP_SOUND); // killough 4/25/98
+      /* cph 20028/10 - for old-school DM addicts, allow old behavior
+       * where only consoleplayer's pickup sounds are heard */
+      if (!comp[comp_sound] || player == &players[consoleplayer])
+        S_StartSound (player->mo, sfx_wpnup|PICKUP_SOUND); // killough 4/25/98
       return false;
     }
 
@@ -604,7 +603,10 @@ void P_TouchSpecialThing(mobj_t *special, mobj_t *toucher)
   P_RemoveMobj (special);
   player->bonuscount += BONUSADD;
 
-  S_StartSound (player->mo, sound | PICKUP_SOUND);   // killough 4/25/98
+  /* cph 20028/10 - for old-school DM addicts, allow old behavior
+   * where only consoleplayer's pickup sounds are heard */
+  if (!comp[comp_sound] || player == &players[consoleplayer])
+    S_StartSound (player->mo, sound | PICKUP_SOUND);   // killough 4/25/98
 }
 
 //
