@@ -1,7 +1,6 @@
 /* Emacs style mode select   -*- C++ -*-
  *-----------------------------------------------------------------------------
  *
- * $Id: p_map.c,v 1.10.2.2 2002/07/20 18:08:36 proff_fs Exp $
  *
  *  PrBoom a Doom port merged with LxDoom and LSDLDoom
  *  based on BOOM, a modified and improved DOOM engine
@@ -31,9 +30,6 @@
  *
  *-----------------------------------------------------------------------------*/
 
-static const char
-rcsid[] = "$Id: p_map.c,v 1.10.2.2 2002/07/20 18:08:36 proff_fs Exp $";
-
 #include "doomstat.h"
 #include "r_main.h"
 #include "p_mobj.h"
@@ -49,7 +45,6 @@ rcsid[] = "$Id: p_map.c,v 1.10.2.2 2002/07/20 18:08:36 proff_fs Exp $";
 #include "lprintf.h"
 
 static mobj_t    *tmthing;
-static uint_64_t tmflags;
 static fixed_t   tmx;
 static fixed_t   tmy;
 static int pe_x; // Pain Elemental position for Lost Soul checks // phares
@@ -232,7 +227,6 @@ boolean P_TeleportMove (mobj_t* thing,fixed_t x,fixed_t y, boolean boss)
   // kill anything occupying the position
 
   tmthing = thing;
-  tmflags = thing->flags;
 
   tmx = x;
   tmy = y;
@@ -557,7 +551,7 @@ static boolean PIT_CheckThing(mobj_t *thing) // killough 3/26/98: make static
   if (thing->flags & MF_SPECIAL)
     {
       uint_64_t solid = thing->flags & MF_SOLID;
-      if (tmflags & MF_PICKUP)
+      if (tmthing->flags & MF_PICKUP)
   P_TouchSpecialThing(thing, tmthing); // can remove thing
       return !solid;
     }
@@ -659,7 +653,6 @@ boolean P_CheckPosition (mobj_t* thing,fixed_t x,fixed_t y)
   subsector_t*  newsubsec;
 
   tmthing = thing;
-  tmflags = thing->flags;
 
   tmx = x;
   tmy = y;
@@ -687,7 +680,7 @@ boolean P_CheckPosition (mobj_t* thing,fixed_t x,fixed_t y)
   validcount++;
   numspechit = 0;
 
-  if ( tmflags & MF_NOCLIP )
+  if ( tmthing->flags & MF_NOCLIP )
     return true;
 
   // Check things first, possibly picking things up.
@@ -2113,7 +2106,7 @@ boolean PIT_GetSectors(line_t* ld)
 // the object resides in.
 
 void P_CreateSecNodeList(mobj_t* thing,fixed_t x,fixed_t y)
-  {
+{
   int xl;
   int xh;
   int yl;
@@ -2122,6 +2115,7 @@ void P_CreateSecNodeList(mobj_t* thing,fixed_t x,fixed_t y)
   int by;
   msecnode_t* node;
   mobj_t* saved_tmthing = tmthing; /* cph - see comment at func end */
+  fixed_t saved_tmx = tmx, saved_tmy = tmy; /* ditto */
 
   // First, clear out the existing m_thing fields. As each node is
   // added or verified as needed, m_thing will be set properly. When
@@ -2136,7 +2130,6 @@ void P_CreateSecNodeList(mobj_t* thing,fixed_t x,fixed_t y)
     }
 
   tmthing = thing;
-  tmflags = thing->flags;
 
   tmx = x;
   tmy = y;
@@ -2188,4 +2181,16 @@ void P_CreateSecNodeList(mobj_t* thing,fixed_t x,fixed_t y)
   if ((compatibility_level < boom_compatibility_compatibility) ||
       (compatibility_level >= prboom_3_compatibility))
     tmthing = saved_tmthing;
+  /* And, duh, the same for tmx/y - cph 2002/09/22
+   * And for tmbbox - cph 2003/08/10 */
+  if ((compatibility_level < boom_compatibility_compatibility) /* ||
+      (compatibility_level >= prboom_4_compatibility) */) {
+    tmx = saved_tmx, tmy = saved_tmy;
+    if (tmthing) {
+      tmbbox[BOXTOP]  = tmy + tmthing->radius;
+      tmbbox[BOXBOTTOM] = tmy - tmthing->radius;
+      tmbbox[BOXRIGHT]  = tmx + tmthing->radius;
+      tmbbox[BOXLEFT]   = tmx - tmthing->radius;
+    }
   }
+}
