@@ -1,7 +1,6 @@
 /* Emacs style mode select   -*- C++ -*-
  *-----------------------------------------------------------------------------
  *
- * $Id: wi_stuff.c,v 1.6.2.1 2002/07/20 18:08:37 proff_fs Exp $
  *
  *  PrBoom a Doom port merged with LxDoom and LSDLDoom
  *  based on BOOM, a modified and improved DOOM engine
@@ -31,9 +30,6 @@
  *-----------------------------------------------------------------------------
  */
 
-static const char
-rcsid[] = "$Id: wi_stuff.c,v 1.6.2.1 2002/07/20 18:08:37 proff_fs Exp $";
-
 #include "doomstat.h"
 #include "m_random.h"
 #include "w_wad.h"
@@ -365,7 +361,7 @@ static const char items[] = {"WIOSTI"};
 static const char frags[] = {"WIFRGS"};
 
 // Time sucks.
-static const char time[] = {"WITIME"};
+static const char time1[] = {"WITIME"};
 static const char par[] = {"WIPAR"};
 static const char sucks[] = {"WISUCKS"};
 
@@ -836,7 +832,7 @@ void WI_initNoState(void)
 
 static void WI_drawTimeStats(int cnt_time, int cnt_total_time, int cnt_par)
 {
-  V_DrawNamePatch(SP_TIMEX, SP_TIMEY, FB, time, CR_DEFAULT, VPT_STRETCH);
+  V_DrawNamePatch(SP_TIMEX, SP_TIMEY, FB, time1, CR_DEFAULT, VPT_STRETCH);
   WI_drawTime(320/2 - SP_TIMEX, SP_TIMEY, cnt_time);
 
   V_DrawNamePatch(SP_TIMEX, (SP_TIMEY+200)/2, FB, total, CR_DEFAULT, VPT_STRETCH);
@@ -1648,7 +1644,7 @@ void WI_updateStats(void)
     cnt_total_time += 3;
 
     if (cnt_total_time >= wbs->totaltimes / TICRATE)
-      cnt_time = plrs[me].stime / TICRATE;
+      cnt_total_time = wbs->totaltimes / TICRATE;
 
     cnt_par += 3;
 
@@ -1656,7 +1652,7 @@ void WI_updateStats(void)
     {
       cnt_par = wbs->partime / TICRATE;
 
-      if ((cnt_time >= plrs[me].stime / TICRATE) && (cnt_total_time >= wbs->totaltimes / TICRATE))
+      if ((cnt_time >= plrs[me].stime / TICRATE) && (compatibility_level < lxdoom_1_compatibility || cnt_total_time >= wbs->totaltimes / TICRATE))
       {
         S_StartSound(0, sfx_barexp);
         sp_state++;
